==> ssp-center-api-0.0.17-lqs16-20170616.024328-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaActivitySlotStatisticsStatService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import cn.com.duiba.tuia.ssp.center.api.dto.MeidaActivitySlotStatisticsDto;
import cn.com.duiba.tuia.ssp.center.api.dto.MeidaActivitySlotStatisticsHourDto;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqActAppStatDailyByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqActAppStatDataByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqActivitySlotDailyDataByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqActivitySlotDataByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqActivityStatDataByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAppDailyStatistics;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAppSlotDailyStatistics;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAppSlotHourStatistics;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAppSlotStatistics;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqAppStatistics;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqSlotStatDailyByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqSlotStatDataByPage;
import cn.com.duiba.tuia.ssp.center.api.dto.ReqUpdateSlotDailyData;
import cn.com.duiba.wolf.dubbo.DubboResult;
import java.util.List;

public interface RemoteMediaActivitySlotStatisticsStatService {
    DubboResult<Integer> selectSlotDataCount(ReqSlotStatDataByPage req);

    DubboResult<Integer> selectSlotDailyDataCount(ReqSlotStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotData(ReqSlotStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyData(ReqSlotStatDailyByPage req);

    DubboResult<Integer> updateSlotDailyData(ReqUpdateSlotDailyData req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppData(ReqAppStatistics req);

    DubboResult<Integer> selectAppDataCount(ReqAppStatistics req);

    DubboResult<Integer> selectAppDailyDataCount(ReqAppDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectAppSlotDailyCount(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotDailyData(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotData(ReqAppSlotStatistics req);

    DubboResult<Integer> selectAppSlotDataCount(ReqAppSlotStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotTotalData(ReqAppStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectActivityMediaSoltAmount(ReqActivitySlotDataByPage param);

    DubboResult<Integer> selectActivitySoltAmount(ReqActivitySlotDataByPage param);

    DubboResult<Integer> selectActivitySoltDailyAmount(ReqActivitySlotDailyDataByPage param);

    DubboResult<Integer> selectActivityStatCount(ReqActivityStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityStatData(ReqActivityStatDataByPage req);

    DubboResult<Integer> selectActAppStatCount(ReqActAppStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatData(ReqActAppStatDataByPage req);

    DubboResult<Integer> selectActAppStatDailyCount(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatDailyData(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityMediaSoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDataByPage(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDailyByPage(ReqActivitySlotDailyDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotDailyDataById(Long id);
}

==> ssp-center-api-0.1.9-lqs3-20170725.061632-1-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteMediaActivitySlotStatisticsStatService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;

import java.util.List;

import cn.com.duiba.tuia.ssp.center.api.dto.*;
import cn.com.duiba.wolf.dubbo.DubboResult;

public interface RemoteMediaActivitySlotStatisticsStatService {
    DubboResult<Integer> selectSlotDataCount(ReqSlotStatDataByPage req);

    DubboResult<Integer> selectSlotDailyDataCount(ReqSlotStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotData(ReqSlotStatDataByPage req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectSumSlotData(ReqSlotStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyData(ReqSlotStatDailyByPage req);

    DubboResult<Integer> updateSlotDailyData(ReqUpdateSlotDailyData req);

    DubboResult<Integer> batchUpdateSlotDailyData(List<ManualSlotDailyStatDto> req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotDailyDataBySlotAndDate(List<ManualSlotDailyStatDto> req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppData(ReqAppStatistics req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSumData(ReqAppStatistics req);

    DubboResult<Integer> selectAppDataCount(ReqAppStatistics req);

    DubboResult<Integer> selectAppDailyDataCount(ReqAppDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectAppSlotDailyCount(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotDailyData(ReqAppSlotDailyStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectAppSlotData(ReqAppSlotStatistics req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectAppSlotSumData(ReqAppSlotStatistics req);

    DubboResult<Integer> selectAppSlotDataCount(ReqAppSlotStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotTotalData(ReqAppStatistics req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectChangeSlotTotalSumData(ReqAppStatistics req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectChangeSlotDailyData(ReqAppDailyStatistics req);

    DubboResult<Integer> selectActivityMediaSoltAmount(ReqActivitySlotDataByPage param);

    DubboResult<Integer> selectActivitySoltAmount(ReqActivitySlotDataByPage param);

    DubboResult<Integer> selectActivitySoltDailyAmount(ReqActivitySlotDailyDataByPage param);

    DubboResult<Integer> selectActivityStatCount(ReqActivityStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityStatData(ReqActivityStatDataByPage req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityStatSumData(ReqActivityStatDataByPage req);

    DubboResult<Integer> selectActAppStatCount(ReqActAppStatDataByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatData(ReqActAppStatDataByPage req);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectActAppStatSumData(ReqActAppStatDataByPage req);

    DubboResult<Integer> selectActAppStatDailyCount(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActAppStatDailyData(ReqActAppStatDailyByPage req);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivityMediaSoltDataByPage(ReqActivitySlotDataByPage param);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectActivityMediaSoltSumData(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDataByPage(ReqActivitySlotDataByPage param);
    
    DubboResult<MeidaActivitySlotStatisticsDto> selectActivitySoltSumData(ReqActivitySlotDataByPage param);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectActivitySoltDailyByPage(ReqActivitySlotDailyDataByPage param);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotDailyDataById(Long id);

    DubboResult<List<MeidaActivitySlotStatisticsDto>> selectSlotActByPage(ReqActivitySlotDataByPage req);

    DubboResult<MeidaActivitySlotStatisticsDto> selectSlotActTotal(ReqActivitySlotDataByPage req);

    DubboResult<Integer> selectSlotActAmount(ReqActivitySlotDataByPage req);

}
